@@ -10,7 +10,6 @@ client side code for requesting a scan, waiting for scan complete, and getting t
 import functools
 import logging
 import pprint
-import sys
 import traceback
 from subprocess import check_output
 from threading import Timer
@@ -18,19 +17,22 @@ from types import SimpleNamespace
 from typing import Union
 
 from . import wlanapi as WLAN_API
-from .wlanapi import (ONEX_NOTIFICATION_TYPE_ENUM,
-                      WLAN_HOSTED_NETWORK_NOTIFICATION_CODE_ENUM,
-                      WLAN_NOTIFICATION_ACM_ENUM, WLAN_NOTIFICATION_MSM_ENUM,
-                      WLAN_NOTIFICATION_SOURCE_ACM,
-                      WLAN_NOTIFICATION_SOURCE_ALL,
-                      WLAN_NOTIFICATION_SOURCE_DICT,
-                      WLAN_NOTIFICATION_SOURCE_HNWK,
-                      WLAN_NOTIFICATION_SOURCE_IHV,
-                      WLAN_NOTIFICATION_SOURCE_MSM,
-                      WLAN_NOTIFICATION_SOURCE_NONE,
-                      WLAN_NOTIFICATION_SOURCE_ONEX,
-                      WLAN_NOTIFICATION_SOURCE_SECURITY,
-                      WLANConnectionAttributes)
+from .wlanapi import (
+    ONEX_NOTIFICATION_TYPE_ENUM,
+    WLAN_HOSTED_NETWORK_NOTIFICATION_CODE_ENUM,
+    WLAN_NOTIFICATION_ACM_ENUM,
+    WLAN_NOTIFICATION_MSM_ENUM,
+    WLAN_NOTIFICATION_SOURCE_ACM,
+    WLAN_NOTIFICATION_SOURCE_ALL,
+    WLAN_NOTIFICATION_SOURCE_DICT,
+    WLAN_NOTIFICATION_SOURCE_HNWK,
+    WLAN_NOTIFICATION_SOURCE_IHV,
+    WLAN_NOTIFICATION_SOURCE_MSM,
+    WLAN_NOTIFICATION_SOURCE_NONE,
+    WLAN_NOTIFICATION_SOURCE_ONEX,
+    WLAN_NOTIFICATION_SOURCE_SECURITY,
+    WLANConnectionAttributes,
+)
 
 
 class Event(object):
@@ -355,11 +357,15 @@ class Client(object):
     async def scan(self):
         try:
             self.log.debug(f"{self.iface.guid}: scan requested...")
-            WLAN_API.WLAN.scan(self.iface.guid)
             self.scan_timer.start()
+            WLAN_API.WLAN.scan(self.iface.guid)
         except WLAN_API.WLANScanError as scan_error:
-            self.log.critical(scan_error)
-            sys.exit(-1)
+            self.log.critical(
+                "Interface (%s) with GUID (%s): %s",
+                self.iface.description,
+                self.iface.guid_string[1:-1],
+                scan_error,
+            )
 
     def lookup_mac_on_guid(self, iface) -> str:
         guid = str(iface.guid)[1:-1]  # remove { } around guid
